@@ -27,8 +27,15 @@ def sanitize(target_list):
 
 def pop():
     sarah = get_coach_data('sarah2.txt')
-    (sarah_name, sarah_dob) = sarah.pop(0), sarah.pop(0)
-    print(sarah_name + " 's fatest times are: " + str(sorted(set([sanitize(t) for t in sarah]))[0:3]))
+
+    '''now use dictionary to refine the below code using list'''
+    sarahDict = {}
+    sarahDict['name'] = sarah.pop(0)
+    sarahDict['dob'] = sarah.pop(0)
+    sarahDict['time'] = sarah
+    print(sarahDict['name']  + " 's fatest times are: " + str(sorted(set([sanitize(t) for t in sarahDict['time']]))[0:3]))
+#    (sarah_name, sarah_dob) = sarah.pop(0), sarah.pop(0)
+#    print(sarah_name + " 's fatest times are: " + str(sorted(set([sanitize(t) for t in sarah]))[0:3]))
 
 
 pop()
